==> igniteui-react-charts-16.6.4.tgz: package/ES2015/igr-scatter-contour-series.js <==
import { IgrValueBrushScale } from "./igr-value-brush-scale";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
export class IgrScatterContourSeries extends IgrScatterTriangulationSeries {
    createImplementation() {
        return new ScatterContourSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
    */
    get valueMemberPath() {
        return this.i.ng;
    }
    set valueMemberPath(v) {
        this.i.ng = v;
    }
    /**
     * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
    */
    get fillScale() {
        if (this.i.nb == null) {
            return null;
        }
        if (!this.i.nb.externalObject) {
            let e = new IgrValueBrushScale(null);
            e._implementation = this.i.nb;
            this.i.nb.externalObject = e;
        }
        return this.i.nb.externalObject;
    }
    set fillScale(v) {
        v == null ? this.i.nb = null : this.i.nb = v.i;
    }
    /**
     * Gets or set the ContourValueResolver used to determine the numeric values of contours.
    */
    get valueResolver() {
        if (this.i.m9 == null) {
            return null;
        }
        return this.i.m9.externalObject;
    }
    set valueResolver(v) {
        v == null ? this.i.m9 = null : this.i.m9 = v.i;
    }
}

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/igr-scatter-contour-series.js <==
import { IgrValueBrushScale } from "./igr-value-brush-scale";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
export class IgrScatterContourSeries extends IgrScatterTriangulationSeries {
    createImplementation() {
        return new ScatterContourSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
    */
    get valueMemberPath() {
        return this.i.ni;
    }
    set valueMemberPath(v) {
        this.i.ni = v;
    }
    /**
     * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
    */
    get fillScale() {
        if (this.i.nd == null) {
            return null;
        }
        if (!this.i.nd.externalObject) {
            let e = new IgrValueBrushScale(null);
            e._implementation = this.i.nd;
            this.i.nd.externalObject = e;
        }
        return this.i.nd.externalObject;
    }
    set fillScale(v) {
        v == null ? this.i.nd = null : this.i.nd = v.i;
    }
    /**
     * Gets or set the ContourValueResolver used to determine the numeric values of contours.
    */
    get valueResolver() {
        if (this.i.nb == null) {
            return null;
        }
        return this.i.nb.externalObject;
    }
    set valueResolver(v) {
        v == null ? this.i.nb = null : this.i.nb = v.i;
    }
}
